ColliderPosition

Struct ColliderPosition 

pub struct ColliderPosition(pub Pose);
The position of a collider.

Tuple Fields

0: Pose

Implementations

Source

impl ColliderPosition

pub fn identity() -> Self

The identity position.

Methods from Deref<Target = Pose>

pub const IDENTITY: Pose2

pub fn inverse(&self) -> Pose2

Returns the inverse of this pose.

pub fn inv_mul(&self, rhs: &Pose2) -> Pose2

Computes self.inverse() * rhs.

pub fn transform_point(&self, p: Vec2) -> Vec2

Transforms a 2D point by this pose.

This applies both the rotation and translation.

pub fn transform_vector(&self, v: Vec2) -> Vec2

Transforms a 2D vector by this pose.

This applies only the rotation (ignores translation).

pub fn inverse_transform_point(&self, p: Vec2) -> Vec2

Transforms a point by the inverse of this pose.

pub fn inverse_transform_vector(&self, v: Vec2) -> Vec2

Transforms a vector by the inverse of this pose.

pub fn lerp(&self, other: &Pose2, t: f32) -> Pose2

Linearly interpolates between two poses.

Uses spherical linear interpolation for the rotation part.

pub fn is_finite(&self) -> bool

Returns true if, and only if, all elements are finite.

pub fn is_nan(&self) -> bool

Returns true if any element is NaN.

pub fn to_mat3(&self) -> Mat3

Converts this pose to a homogeneous 3x3 matrix.