pub struct PolylineFlags(/* private fields */);Expand description
Controls how a Polyline is loaded.
Implementations
Sourceimpl PolylineFlags
impl PolylineFlags
Sourcepub const ORIENTED: PolylineFlags
pub const ORIENTED: PolylineFlags
If set, the polyline is treated as one-sided: a pseudo-normal is computed at every
vertex and contact normals are clamped to the outward side, the right of each
segment’s direction. The solid must be wound counter-clockwise, so the outward side is
on the right. This removes the spurious sideways push a body gets at a convex corner of
a double-sided polyline. This one flag covers what TriMesh splits across
TriMeshFlags::ORIENTED (compute pseudo-normals) and TriMeshFlags::FIX_INTERNAL_EDGES
(use them to clamp contacts).
Sourceimpl PolylineFlags
impl PolylineFlags
Sourcepub const fn empty() -> PolylineFlags
pub const fn empty() -> PolylineFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> PolylineFlags
pub const fn all() -> PolylineFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<PolylineFlags>
pub const fn from_bits(bits: u8) -> Option<PolylineFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> PolylineFlags
pub const fn from_bits_truncate(bits: u8) -> PolylineFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> PolylineFlags
pub const fn from_bits_retain(bits: u8) -> PolylineFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PolylineFlags>
pub fn from_name(name: &str) -> Option<PolylineFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PolylineFlags) -> bool
pub const fn intersects(&self, other: PolylineFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: PolylineFlags) -> bool
pub const fn contains(&self, other: PolylineFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: PolylineFlags)
pub fn insert(&mut self, other: PolylineFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: PolylineFlags)
pub fn remove(&mut self, other: PolylineFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PolylineFlags)
pub fn toggle(&mut self, other: PolylineFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: PolylineFlags, value: bool)
pub fn set(&mut self, other: PolylineFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: PolylineFlags) -> PolylineFlags
pub const fn intersection(self, other: PolylineFlags) -> PolylineFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: PolylineFlags) -> PolylineFlags
pub const fn union(self, other: PolylineFlags) -> PolylineFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: PolylineFlags) -> PolylineFlags
pub const fn difference(self, other: PolylineFlags) -> PolylineFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: PolylineFlags) -> PolylineFlags
pub const fn symmetric_difference(self, other: PolylineFlags) -> PolylineFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> PolylineFlags
pub const fn complement(self) -> PolylineFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PolylineFlags
impl PolylineFlags
Sourcepub const fn iter(&self) -> Iter<PolylineFlags>
pub const fn iter(&self) -> Iter<PolylineFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PolylineFlags>
pub const fn iter_names(&self) -> IterNames<PolylineFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.