Aabb

Type Alias Aabb 

pub type Aabb = Aabb;
An axis-aligned bounding box.

Aliased Type

#[repr(C)]
pub struct Aabb { pub mins: Vec2, pub maxs: Vec2, }

Fields

mins: Vec2

The point with minimum coordinates (bottom-left-back corner).

Each component (x, y, z) should be less than or equal to the corresponding component in maxs.

maxs: Vec2

The point with maximum coordinates (top-right-front corner).

Each component (x, y, z) should be greater than or equal to the corresponding component in mins.