pub struct ColliderPosition(pub Pose);Expand description
The position of a collider.
Tuple Fields
0: PoseImplementations
Methods from Deref<Target = Pose>
pub const IDENTITY: Pose2
Sourcepub fn transform_point(&self, p: Vec2) -> Vec2
pub fn transform_point(&self, p: Vec2) -> Vec2
Transforms a 2D point by this pose.
This applies both the rotation and translation.
Sourcepub fn transform_vector(&self, v: Vec2) -> Vec2
pub fn transform_vector(&self, v: Vec2) -> Vec2
Transforms a 2D vector by this pose.
This applies only the rotation (ignores translation).
Sourcepub fn inverse_transform_point(&self, p: Vec2) -> Vec2
pub fn inverse_transform_point(&self, p: Vec2) -> Vec2
Transforms a point by the inverse of this pose.
Sourcepub fn inverse_transform_vector(&self, v: Vec2) -> Vec2
pub fn inverse_transform_vector(&self, v: Vec2) -> Vec2
Transforms a vector by the inverse of this pose.