pub type Ray = Ray;Expand description
A ray that can be cast against colliders.
Aliased Type
#[repr(C)]pub struct Ray {
pub origin: Vec2,
pub dir: Vec2,
}Fields
origin: Vec2Starting point of the ray.
This is where the ray begins. Vectors along the ray are computed as
origin + dir * t for t ≥ 0.
dir: Vec2Direction vector of the ray.
This vector points in the direction the ray travels. It does NOT need to be normalized, but using a normalized direction makes time-of-impact values represent actual distances.